@@ -14,12 +14,13 @@ split_by <- function(x, ...) {
 #' @export
 split_by.tbl_ts <- function(x, ...) {
   quos <- enquos(...)
-  if (is_empty(quos)) {
-    return(list(x))
-  }
+  if (is_empty(quos)) return(list(x))
+
   vars_split <- validate_vars(quos, names(x))
-  idx <- attr(grouped_df(x, vars = vars_split), "indices")
-  lapply(idx, function(idx) x[idx + 1, , drop = FALSE])
+  grped_df <- grouped_df(x, vars = vars_split)
+  idx <- attr(grped_df, "indices")
+  uni_idx <- unique(group_indices(grped_df))
+  lapply(idx, function(idx) x[idx + 1, , drop = FALSE])[uni_idx]
 }
 
 #' @export
