@@ -50,7 +50,7 @@ df <- data.frame(time = x, value = rnorm(10))
 tsbl <- as_tsibble(df, index = time)
 
 test_that("POSIXct with 1 microseconds interval", {
-  expect_output(print(tsbl), cat("A tsibble: 10 x 2 [10\xC2\xB5s]"))
+  expect_output(print(tsbl), cat("A tsibble: 10 x 2 [10\U00B5s]"))
 })
 
 library(nanotime)
@@ -237,7 +237,8 @@ dat_x <- tibble(
 )
 
 test_that("A single key", {
-  expect_error(as_tsibble(dat_x, index = date))
+  expect_error(as_tsibble(dat_x, index = date), "Invalid")
+  expect_error(as_tsibble(dat_x, key = "group", index = date), "Can't")
   tsbl <- as_tsibble(dat_x, key = id(group), index = date)
   expect_output(print(tsbl), "A tsibble: 10 x 3 \\[1D\\]")
   expect_is(key(tsbl), "key")
@@ -378,7 +379,11 @@ test_that("build_tsibble()", {
   ), "`interval` must be the `interval` class")
   expect_error(
     build_tsibble(pedestrian, key = Sensor, index = Date_Time),
-    "Have you forgotten"
+    "Can't"
+  )
+  expect_error(
+    build_tsibble(pedestrian, key = dplyr::vars(Sensor), index = Date_Time),
+    "Please use"
   )
 
   tsbl <- build_tsibble(
